// Sample dataset with multiple categories and their values
const dataset = [
  { category: 'Category 1', value1: 20, value2: 30, value3: 10 },
  { category: 'Category 2', value1: 40, value2: 25, value3: 15 },
  { category: 'Category 3', value1: 15, value2: 35, value3: 20 },
  // Add more data as needed
];

// Set up chart dimensions
const width = 400;
const height = 300;
const margin = { top: 20, right: 30, bottom: 30, left: 40 };
const chartWidth = width - margin.left - margin.right;
const chartHeight = height - margin.top - margin.bottom;

// Create the SVG element
const svg = d3.select('#chart')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// Create the chart group
const chart = svg.append('g')
  .attr('transform', `translate(${margin.left}, ${margin.top})`);

// Create x and y scales
const xScale = d3.scaleBand()
  .domain(dataset.map(d => d.category))
  .range([0, chartWidth])
  .padding(0.2);

const yScale = d3.scaleLinear()
  .domain([0, d3.max(dataset, d => d3.sum([d.value1, d.value2, d.value3]))])
  .range([chartHeight, 0]);

// Create and append the stacked bars
const stack = d3.stack()
  .keys(['value1', 'value2', 'value3'])
  .order(d3.stackOrderNone)
  .offset(d3.stackOffsetNone);

const stackedData = stack(dataset);

chart.selectAll('g')
  .data(stackedData)
  .enter()
  .append('g')
  .attr('fill', (d, i) => ['steelblue', 'green', 'orange'][i])
  .selectAll('rect')
  .data(d => d)
  .enter()
  .append('rect')
  .attr('x', d => xScale(d.data.category))
  .attr('y', d => yScale(d[1]))
  .attr('height', d => yScale(d[0]) - yScale(d[1]))
  .attr('width', xScale.bandwidth());

// Add x-axis
chart.append('g')
  .attr('transform', `translate(0, ${chartHeight})`)
  .call(d3.axisBottom(xScale));

// Add y-axis
chart.append('g')
  .call(d3.axisLeft(yScale));
